#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MINNUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MINNUM_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/minnum.hpp>

#endif
